Shell resource client
Shell resource client
A R6 object of class ShellResourceClient
resourcer::ResourceClient -> resourcer::CommandResourceClient -> ShellResourceClient
new()Create a ShellResourceClient instance. This client will interact wtih a computation resource using shell commands.
ShellResourceClient$new(resource)
resourceThe computation resource.
The ShellResourceClient object.
downloadFile()Copy one or more files (wilcard * is supported in the file name (which can be a directory))
ShellResourceClient$downloadFile(file, to = ".", verbose = FALSE)
fileThe file to copy.
toThe copy destination.
verboseIf TRUE, details the file operations on the console output.
The path to the files having been copied.
exec()Executes a shell command in the working directory specified in the resource's URL.
ShellResourceClient$exec(command, params = NULL, test = FALSE)
commandThe command name.
paramsA named list of parameters.
testIf TRUE, the command is printed but not executed (for debugging).
The command execution result object.
clone()The objects of this class are cloneable with this method.
ShellResourceClient$clone(deep = FALSE)
deepWhether to make a deep clone.
Executes local system shell commands.