SSH resource client
SSH resource client
A R6 object of class SshResourceClient
resourcer::ResourceClient -> resourcer::CommandResourceClient -> SshResourceClient
new()Create a SshResourceClient instance. This client will interact wtih a computation resource using ssh commands.
SshResourceClient$new(resource)
resourceThe computation resource.
The SshResourceClient object.
getConnection()Get or create the SSH connection object, for raw interaction.
SshResourceClient$getConnection()
The SSH connection object.
downloadFile()Download one or more files (wilcard * is supported in the file name (which can be a directory))
SshResourceClient$downloadFile(file, to = ".", verbose = FALSE)
fileThe file to download.
toThe download destination.
verboseIf TRUE, details the file operations on the console output.
The paths of the files having been downloaded.
exec()Executes a ssh command.
SshResourceClient$exec(command, params = NULL, test = FALSE)
commandThe command name.
paramsA named list of parameters.
testIf TRUE, the command is printed but not executed (for debugging).
The command execution result object.
close()Close the SSH connection.
SshResourceClient$close()
clone()The objects of this class are cloneable with this method.
SshResourceClient$clone(deep = FALSE)
deepWhether to make a deep clone.
Connects to a SSH server.